@@ -14,6 +14,7 @@
 #                The response must be a survival object                        #
 #                as returned by the Surv function.                             #
 #   - cluster  : the name of the variable in data containing cluster IDs       #
+#   - strata   : the name of the variable in data containing strata IDs        #
 #   - data     : a data.frame in which to interpret the variables named        #
 #                in the formula.                                               #
 #   - dist     : the vector of the names of the baseline hazards               #
@@ -41,11 +42,12 @@
 #                                                                              #
 #                                                                              #
 #   Date: December 21, 2011                                                    #
-#   Last modification on: January, 12, 2012                                    #
+#   Last modification on: April 16, 2012                                       #
 ################################################################################
 
 select.parfm <- function(formula,
                          cluster=NULL,
+                         strata=NULL,
                          data,
                          inip=NULL,
                          iniFpar=NULL,
@@ -68,7 +70,13 @@ select.parfm <- function(formula,
   res <- list(AIC=NULL, BIC=NULL)
   res$AIC <- res$BIC <- matrix(NA, length(dist), length(frailty),
                                dimnames=list(dist, frailty))
-  cat("             Frailty\nBaseline    ")
+  cat(paste("\n\n### - Parametric frailty models - ###",
+            "Progress status:",
+            "  'ok' = converged",
+            "  'nc' = not converged\n",
+            "             Frailty",
+            "Baseline    ",
+            sep="\n"))
   cat(c(none=" None  ", gamma=" Gamma ", ingau=" InvGau", possta=" PosSta")[frailty]
     
   )
@@ -83,6 +91,7 @@ select.parfm <- function(formula,
       cat("..")
       model <- try(parfm(formula=formula, 
                          cluster=cluster,
+                         strata=strata,
                          data=data,
                          inip=inip,
                          iniFpar=iniFpar,
@@ -97,8 +106,8 @@ select.parfm <- function(formula,
       if (!("try-error" %in% class(model))){
         res$AIC[d, f] <- AIC(model)
         res$BIC[d, f] <- BIC(model)
-      }
-      cat("ok....")
+        cat("ok....")
+      } else cat("nc....")
     }
   }
   cat("\n")
